@@ -54,7 +54,9 @@ def delete_or_downsize_instance_recommendation(self) -> list:
                                 'Average CPU Datapoints(7 days)': [float('{:.2f}'.format(x)) for x in tmp_lst_cpu]
                             },
                             'Risk': 'High',
-                            'Savings': None
+                            'Savings': None,
+                            'Source': 'Klera',
+                            'Category': 'Cost Optimization'
                         }
                         recommendation.append(temp)
                     else:
@@ -83,7 +85,9 @@ def delete_or_downsize_instance_recommendation(self) -> list:
                                     'Average CPU Datapoints(7 days)': [float('{:.2f}'.format(x)) for x in tmp_lst_cpu]
                                 },
                                 'Risk': 'High',
-                                'Savings': None
+                                'Savings': None,
+                                'Source': 'Klera',
+                                'Category': 'Cost Optimization'
                             }
                             recommendation.append(temp)
 
@@ -102,7 +106,9 @@ def delete_or_downsize_instance_recommendation(self) -> list:
                         'Access Denied'
                     },
                     'Risk': 'High',
-                    'Savings': None
+                    'Savings': None,
+                    'Source': 'Klera',
+                    'Category': 'Cost Optimization'
                 }
                 recommendation.append(temp)
                 return recommendation
@@ -158,7 +164,9 @@ def purge_unattached_vol_recommendation(self) -> list:
                                     'reason': 'This Volume is 4 weeks older and is not attached to any instance'
                                 },
                                 'Risk': 'Medium',
-                                'Savings': None
+                                'Savings': None,
+                                'Source': 'Klera',
+                                'Category': 'Cost Optimization'
                             }
                             recommendation.append(temp)
                 try:
@@ -183,7 +191,9 @@ def purge_unattached_vol_recommendation(self) -> list:
                         'Access Denied'
                     },
                     'Risk': 'Medium',
-                    'Savings': None
+                    'Savings': None,
+                    'Source': 'Klera',
+                    'Category': 'Cost Optimization'
                 }
                 recommendation.append(temp)
                 return recommendation
@@ -245,7 +255,9 @@ def purge_8_weeks_older_snapshots(self) -> list:
                             'Metadata': metadata,
                             'Recommendation Reason': reason,
                             'Risk': 'Low',
-                            'Savings': None
+                            'Savings': None,
+                            'Source': 'Klera',
+                            'Category': 'Cost Optimization'
                         }
                         recommendation.append(temp)
 
@@ -270,7 +282,9 @@ def purge_8_weeks_older_snapshots(self) -> list:
                         'Access Denied'
                     },
                     'Risk': 'Low',
-                    'Savings': None
+                    'Savings': None,
+                    'Source': 'Klera',
+                    'Category': 'Cost Optimization'
                 }
                 recommendation.append(temp)
                 return recommendation
@@ -281,7 +295,6 @@ def purge_8_weeks_older_snapshots(self) -> list:
 # Generates the recommendations fot amazon ec2 reserved instance lease expiration
 def reserved_instance_lease_expiration(self) -> list:
     """
-
     :param self:
     :return list: list of recommendations for reserved instances for lease expiration
     """
@@ -325,7 +338,9 @@ def reserved_instance_lease_expiration(self) -> list:
                             'Reason': 'The Instance is either expired within 30 days or will be expiring in next 30 days'
                         },
                         'Risk': 'High',
-                        'Savings': None
+                        'Savings': None,
+                        'Source': 'Klera',
+                        'Category': 'Cost Optimization'
                     }
                     recommendation.append(temp)
 
@@ -344,7 +359,9 @@ def reserved_instance_lease_expiration(self) -> list:
                         'Access Denied'
                     },
                     'Risk': 'High',
-                    'Savings': None
+                    'Savings': None,
+                    'Source': 'Klera',
+                    'Category': 'Cost Optimization'
                 }
                 recommendation.append(temp)
                 return recommendation
@@ -356,7 +373,6 @@ def reserved_instance_lease_expiration(self) -> list:
 # Generated recommendations for unassociated elastic IP addresses
 def unassociated_elastic_ip_addresses(self) -> list:
     """
-
     :param self:
     :return list: list of recommendations for unassociated elastic ip addresses
     """
@@ -392,7 +408,9 @@ def unassociated_elastic_ip_addresses(self) -> list:
                             'Reason': 'An allocated Elastic IP address (EIP) is not associated with a running Amazon EC2 instance'
                         },
                         'Risk': 'Low',
-                        'Savings': '$3.65'
+                        'Savings': '$3.65',
+                        'Source': 'Klera',
+                        'Category': 'Cost Optimization'
                     }
                     recommendation.append(temp)
 
@@ -411,7 +429,9 @@ def unassociated_elastic_ip_addresses(self) -> list:
                         'Access Denied'
                     },
                     'Risk': 'Low',
-                    'Savings': None
+                    'Savings': None,
+                    'Source': 'Klera',
+                    'Category': 'Cost Optimization'
                 }
                 recommendation.append(temp)
                 return recommendation
@@ -477,7 +497,9 @@ def unused_ami(self) -> list:
                                 'Reason': 'AMI is not used anymore and can be safely removed'
                             },
                             'Risk': 'Low',
-                            'Savings': None
+                            'Savings': None,
+                            'Source': 'Klera',
+                            'Category': 'Cost Optimization'
                         }
                 try:
                     marker = response_ami['NextToken']
@@ -501,7 +523,9 @@ def unused_ami(self) -> list:
                         'Access Denied'
                     },
                     'Risk': 'Low',
-                    'Savings': None
+                    'Savings': None,
+                    'Source': 'Klera',
+                    'Category': 'Cost Optimization'
                 }
                 recommendation.append(temp)
                 return recommendation
